# PC Web Integration Specification V4.3.1
[Shanghai AllPay Technology Co., Ltd.](https://www.allpayx.com)

* Version:English V4.3.1
* Update Time:11 2018

#### 1.Overview

AllPay provides customers with unified API access to help them implement fast, secure and centralized access payment channels.
#### 2.Transaction process 
![image](https://git.allpayx.com/OpenAPI/b2c/raw/master/images/pc_flowsheet.png)



#### 3. Description of verifying the signature  
```
1.For a POST request message sent to the ALLPAY system, in which all incoming parameters (except signature parameters) according to the field name of ASCII smallest sequence (dictionary), using the format of the URL key/value pair (key1 = value1 & key2 = value2... ) spliced into a string String1.

2.At the end of String1, the signature key K1(assigned at ALLPAY upon access) agreed by both parties is spliced directly (no need to connect with "&"), resulting in a stringSignTemp string, and an md5 operation on stringSignTemp to get the value of signature.

3.Sample signature string:acqID=99020344&backURL=https://www.baidu.com&charSet=UTF-8&frontURL=nil&goodsInfo=iPhone x&merID=800039253992510&merReserve=&orderAmount=1.00&orderCurrency=INR&orderNum=ap0180417163142&paymentSchema=EB&signType=MD5&transTime=20180417163142&transType=PURC&trxn_email_id=benson.zhang@allpayx.com&trxn_firstname=benson zhang&trxn_is_coupon_enabled=1&trxn_phone=15026528888&unique_id=abcde12345&version=VER000000002f3e0e436cd24430aa4aaaed597450f26 
```


#### 4. Common interface

Common interface includes notification, asynchronous notification of transactions, transaction inquiry, refund, refund inquiry interface

##### 4.1. General API access address

| Interface Name | Test URL                                  | Production URL                        |
| -------------- | ----------------------------------------- | ------------------------------------- |
| Purchase       | https://testapi.allpayx.com/pay           | https://api.allpayx.com/pay           |
| Inquiry        | <https://testapi.allpayx.com/pay>         | <https://api.allpayx.com/pay>         |
| Refund         | <https://testapi.allpayx.com/refund>      | <https://api.allpayx.com/refund>      |
| Refund inquiry | <https://testapi.allpayx.com/refundquery> | <https://api.allpayx.com/refundquery> |

##### 4.2. Purchase interface

1.Request message format

This field is a list of common fields, sending, every channel needs some channel channel exclusive field, specific fields please go to the channel's exclusive canal to the fields that view. Consumer interface is divided into jump transformation and parameters return type, default to jump transformation, parameters return type will be explained in chapter 4 channels (exclusive) inside.

| Parameter     | Type         | Required | Description                                                  |
| ------------- | ------------ | -------- | ------------------------------------------------------------ |
| version       | String(12)   | M        | "VER000000002"                                               |
| charSet       | String(6)    | M        | “UTF-8”                                                      |
| transType     | String(4)    | M        | “PURC”                                                       |
| orderNum      | String(60)   | M        | Order number: it is defined by the merchant itself, and the order number must not be repeated for the same merchant number |
| orderAmount   | String(12)   | M        | Order amount: if 100 yuan, it will be 100 or 100.00          |
| orderCurrency | String(3)    | M        | Currency of the order: ISO standard, such as RMB filling in "CNY", US dollar filling in "USD" |
| frontURL      | String(400)  | M        | When the payment is complete, jump to the address            |
| backURL       | String(400)  | M        | Payment results are asynchronously notified to this address  |
| merReserve    | String(1024) | M        | Merchant reserved content, can pass any content, such as purchase information, account number, etc., but do not pass special symbols, such as commas. |
| merID         | String(15)   | M        | Merchant ID, assigned by AllPay                              |
| acqID         | String(11)   | M        | "99020344"                                                   |
| paymentSchema | String(10)   | M        | Channel code：[Click Here](https://git.allpayx.com/OpenAPI/b2c_pc_payment/src/master/paymentSchema.md) |
| goodsInfo     | String(60)   | M        | Commodity information, displayed on the payment page         |
| detailInfo    | String(400)  | M        | Product details format: [{"goods_name":"iPhone X","quantity":"2"},{"goods_name":"iPhone 8","quantity":"4"}], which requires base-64 encoding of this field before signing and sending. |
| transTime     | String(14)   | M        | Transaction time, format :" yyymmddhhmmss"                   |
| signType      | String(3)    | M        | MD5                                                          |
| signature     | String(32)   | M        | MD5 signature                                                |



2.Jump transformation Purchase interface response message

	The merchant needs to provide an HTTP/HTTPS protocol interface that is included in the parameters passed to the SDK, the backURL. After the payment is complete, the AllPay server will call the backURL as a Get, informing the payment result. 



| Parameter     | Type         | Required | Description                                                  |
| ------------- | ------------ | -------- | ------------------------------------------------------------ |
| version       | String(12)   | M        | "VER000000002"                                               |
| charSet       | String(6)    | M        | “UTF-8”                                                      |
| transType     | String(4)    | M        | “PURC”                                                       |
| orderNum      | String(60)   | M        | Order number                                                       |
| orderAmount   | String(12)   | M        | Order amount: if 100 yuan, it will be 100 or 100.00          |
| orderCurrency | String(3)    | M        | Currency of the order: ISO standard, such as RMB filling in "CNY", us dollar filling in "USD" |
| settAmount    | String(12)   | M        | 100 is displayed as 100 or 100.00                            |
| settCurrency  | String(3)    | M        | Comply with ISO standards                                    |
| rate          | String(7)    | M        | Real exchange rate, 7 digits                                 |
| merReserve    | String(1024) | M        | Merchant reserved content, can pass any content, such as purchase information, account number, etc., but do not pass special symbols, such as commas. |
| transID       | String(32)   | M        | The unique transaction id generated by the gateway.          |
| merID         | String(15)   | M        | Merchant ID, assigned by AllPay                              |
| acqID         | String(11)   | M        | "99020344"                                                   |
| paymentSchema | String(10)   | M        | Channel code：[Click Here](https://git.allpayx.com/OpenAPI/b2c_pc_payment/src/master/paymentSchema.md) |
| RespCode      | String(2)    | M        | 00 stands for success; 01 stands for fail.                   |
| RespMsg       | String(20)   | M        | Response message, all English characters                     |
| transTime     | String(14)   | M        | Transaction time, format :" yyymmddhhmmss"                   |
| GWTime        | String(14)   | M        | YYYYMMDDHHMMSS this should be a GWtime, currently is local transaction time |
| signType      | String(3)    | M        | MD5                                                          |
| signature     | String(32)   | M        | MD5 signature                                                |





##### 4.3. Inqiury interface 



1.Interface specification

 This interface provides the function of inqiury transaction for access merchants.

2.Request message format 

  

| Parameter     | Type         | Required | Description                                                  |
| ------------- | ------------ | -------- | ------------------------------------------------------------ |
| version       | String(12)   | M        | "VER000000002"                                               |
| charSet       | String(6)    | M        | "UTF-8"                                                      |
| transType     | String(4)    | M        | "INQY"                                                       |
| orderNum      | String(60)   | M        | Original trade order number                                  |
| merReserve    | String(1024) | M        | Merchant reserved content, can pass any content, such as purchase information, account number, etc., but do not pass special symbols, such as commas. |
| merID         | String(15)   | M        | Merchant ID, assigned by AllPay                              |
| acqID         | String(11)   | M        | "99020344"                                                   |
| paymentSchema | String(10)   | M        | Channel code：[Click Here](https://git.allpayx.com/OpenAPI/b2c_pc_payment/src/master/paymentSchema.md) |
| transTime     | String(14)   | M        | Transaction time, format :" yyymmddhhmmss"                   |
| signType      | String(3)    | M        | "MD5"                                                        |
| signature     | String(32)   | M        | MD5 signature                                                |



3.Response message format

| Parameter     | Type       | Required | Description                                                  |
| ------------- | ---------- | -------- | ------------------------------------------------------------ |
| version       | String(12) | M        | "VER000000002"                                               |
| charSet       | String(6)  | M        | “UTF-8”                                                      |
| transType     | String(4)  | M        | “INQY”                                                       |
| orderNum      | String(60) | M        | Original trade order number                                  |
| transID       | String(32) | M        | The unique transaction id generated by the gateway.          |
| merID         | String(15) | M        | Merchant ID, assigned by AllPay                              |
| acqID         | String(11) | M        | "99020344"                                                   |
| paymentSchema | String(10) | M        | Channel code：[Click Here](https://git.allpayx.com/OpenAPI/b2c_pc_payment/src/master/paymentSchema.md) |
| RespCode      | String(2)  | M        | 00 stands for success; 01 stands for fail.                   |
| RespMsg       | String(20) | M        | Response message, all English characters                     |
| transTime     | String(14) | M        | Transaction time, format :" yyymmddhhmmss"                   |
| GWTime        | String(14) | M        | YYYYMMDDHHMMSS this should be a GWtime, currently is local transaction time |
| signType      | String(3)  | M        | MD5                                                          |
| signature     | String(32) | M        | signature                                                    |



##### 4.4. Refund interface

1.Interface specification 

This interface provides the function of refund transaction for access merchants. 

2.Request message format 



| Parameter     | Type         | Required | Description                                                  |
| ------------- | ------------ | -------- | ------------------------------------------------------------ |
| version       | String(12)   | M        | “VER000000002”                                               |
| charSet       | String(6)    | M        | “UTF-8”                                                      |
| transType     | String(4)    | M        | “REFD”                                                       |
| orderNum      | String(60)   | M        | Original trade order number                                  |
| refundNum     | String(60)   | M        | Refund order number: it is defined by the merchant, and the refund order number under the same merchant number cannot be repeated |
| returnAmount  | String(12)   | M        | Refund amount: if 100 yuan, it is 100 or 100.00              |
| orderCurrency | String(3)    | M        | Currency of the order: ISO standard, such as RMB filling in "CNY", us dollar filling in "USD" |
| merReserve    | String(1024) | M        | Merchant reserved content, can pass any content, such as purchase information, account number, etc., but do not pass special symbols, such as commas. |
| merID         | String(15)   | M        | Merchant ID, assigned by AllPay                              |
| acqID         | String(11)   | M        | "99020344"                                                   |
| paymentSchema | String(10)   | M        | Channel code：[Click Here](https://git.allpayx.com/OpenAPI/b2c_pc_payment/src/master/paymentSchema.md) |
| transTime     | String(14)   | M        | Transaction time, format :" yyymmddhhmmss"                   |
| signType      | String(3)    | M        | MD5                                                          |
| signature     | String(32)   | M        | signature                                                    |

3.Response message format

| Parameter | Type       | Required | Description                                                  |
| --------- | ---------- | -------- | ------------------------------------------------------------ |
| version   | String(12) | M        | “VER000000002”                                               |
| charSet   | String(6)  | M        | “UTF-8”                                                      |
| transType | String(4)  | M        | “REFD”                                                       |
| refundNum | String(60) | M        | The merchant shall define it by itself, and the refund number of the same merchant number shall not be repeated |
| transID   | String(32) | M        | The unique transaction id generated by the gateway.          |
| merID     | String(15) | M        | Merchant ID, assigned by AllPay                              |
| acqID     | String(11) | M        | "99020344"                                                   |
| RespCode  | String(2)  | M        | 00 stands for success; 01 stands for fail.                   |
| RespMsg   | String(20) | M        | Response message, all English characters                     |
| transTime | String(14) | M        | Transaction time, format :" yyymmddhhmmss"                   |
| GWTime    | String(14) | M        | YYYYMMDDHHMMSS this should be a GWtime, currently is local transaction time |
| signType  | String(3)  | M        | MD5                                                          |
| signature | String(32) | M        | signature                                                    |



##### 4.5. Refund Inqiury interface

1.Interface specification

 This interface provides the function of Refund inqiury transaction for access merchants.

2.Request message format 

  

| Parameter     | Type         | Required | Description                                                  |
| ------------- | ------------ | -------- | ------------------------------------------------------------ |
| version       | String(12)   | M        | “VER000000002”                                               |
| charSet       | String(6)    | M        | “UTF-8”                                                      |
| transType     | String(4)    | M        | “RFQY”                                                       |
| refundNum     | String(60)   | M        | Refund order number                                          |
| merReserve    | String(1024) | M        | Merchant reserved content, can pass any content, such as purchase information, account number, etc., but do not pass special symbols, such as commas. |
| merID         | String(15)   | M        | Merchant ID, assigned by AllPay                              |
| acqID         | String(11)   | M        | "99020344"                                                   |
| paymentSchema | String(10)   | M        | Channel code：[Click Here](https://git.allpayx.com/OpenAPI/b2c_pc_payment/src/master/paymentSchema.md) |
| transTime     | String(14)   | M        | Transaction time, format :" yyymmddhhmmss"                   |
| signType      | String(3)    | M        | MD5                                                          |
| signature     | String(32)   | M        | signature                                                    |



3.Response message format

| Parameter     | Type       | Required | Description                                                  |
| ------------- | ---------- | -------- | ------------------------------------------------------------ |
| version       | String(12) | M        | “VER000000002”                                               |
| charSet       | String(6)  | M        | “UTF-8”                                                      |
| transType     | String(4)  | M        | “REFD”                                                       |
| refundNum     | String(60) | M        | Refund order number                                          |
| transID       | String(32) | M        | The unique transaction id generated by the gateway.          |
| merID         | String(15) | M        | Merchant ID, assigned by AllPay                              |
| acqID         | String(11) | M        | "99020344"                                                   |
| paymentSchema | String(10) | M         | Channel code：[Click Here](https://git.allpayx.com/OpenAPI/b2c_pc_payment/src/master/paymentSchema.md) |
| RespCode      | String(2)  | M        | Response message, all English characters                     |
| RespMsg       | String(20) | M        | Response message, all English characters                     |
| transTime     | String(14) | M        | Transaction time, format :" yyymmddhhmmss"                   |
| GWTime        | String(14) | M        | YYYYMMDDHHMMSS this should be a GWtime, currently is local transaction time |
| signType      | String(3)  | M        | MD5                                                          |
| signature     | String(32) | M        | signature                                                    |



#### 5.Channel exclusive allocation

##### 5.1 EB(Transition）

| No.  | Field Name | Max.Length | Type | Parameter name | Comment                                                    |
| ---- | ---------- | ---------- | ---- | -------------- | ---------------------------------------------------------- |
| 1    | Name       | 32         | Text | trxn_firstname | This is name of the customer who is doing the transaction. |
| 2    | Email      | 40         | Text | trxn_email_id  | this is email id of the customer who is doing transaction. |
| 3    | Phone      | 20         | Text | trxn_phone     | Phone number of the customer.                              |

##### 5.2 UP(Transition）

| No.  | Field Name           | Max.Length | Type | Parameter name | Comment                                                      |
| ---- | -------------------- | ---------- | ---- | -------------- | ------------------------------------------------------------ |
| 1    | UnionPay card number | 19         | Text | uCardNumber    | The overseas UnionPay channel is applicable to the UnionPay excellent plan. Can not upload, if you need to fill in the bank card number in advance, then send this field. |

```javascript
Test cards:

Credit Card: 5200831111111113
Mobile: 13552535506
CVN2: 123
Exp Date: month 11 year 19
SMS Code on PC: 111111
SMS Code on Mobile: 123456

Credit Card: 6226388000000095
Mobile: 18100000000
CVN2: 248
Exp Date: month 12 year 19
SMS Code on PC: 111111
SMS Code on Mobile: 123456
```

##### 5.3 WX(Includes transition and parameter return）

| No.  | Field Name                | Max.Length | Type | Parameter name | Comment                                                      |
| ---- | ------------------------- | ---------- | ---- | -------------- | ------------------------------------------------------------ |
| 1    | Transaction scenario code | 16         | Text | code           | 1.“NATIVE“：Return the URL value of WeChat payment collection for parameter return, ask the merchant to convert it into QR code, generate the front interface of payment, and prompt the user to scan the code to pay; 2.“QUICK”：It's jump mode, open the front-end page provided by AllPay, which contains WeChat QR code. |

##### 5.4 PPRO(Transition）

##### 5.4.1 PPRO_AC

| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |
| consumerref       | M    | Text | Unique reference identifying the consumer, has to satisfy the regular expression [A-Za-z0-9.%,&/+*$-]{1,20} |

Note: AstroPay Card is available for currency USD and country codes BO, BR, CL, CN, CO, CR, MX, PE, UY, VE. 
​     

##### 5.4.2 PPRO_AD

| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |
| consumerref       | M    | Text | Unique reference identifying the consumer, has to satisfy the regular expression [A-Za-z0-9.%,&/+*$-]{1,20} |

Note: AstroPay Direct is available for currency USD and country codes AR, BR, CL, CN, CO, MX, PE, UY, CN 

##### 5.4.3 PPRO_AR

| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |
| consumerref       | M    | Text | Unique reference identifying the consumer, has to satisfy the regular expression [A-Za-z0-9.%,&/+*$-]{1,20} |
| nationalid        | M    | Text | Consumer’s national id (up to 30 characters)                 |
| email             | M    | Text | RFC compliant email address of the account holder            |
| address           | M    | Text | Consumer's address                                           |
| zipcode           | M    | Text | Consumer's zip/postal code                                   |
| dob               | O    | Text | Date of birth, format YYYYMMDD                               |



Note: Aura (Brazil) is available for currency USD and country code BR. 

##### 5.4.4 PPRO_BA

| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |
| consumerref       | M    | Text | Unique reference identifying the consumer, has to satisfy the regular expression [A-Za-z0-9.%,&/+*$-]{1,20} |
| nationalid        | M    | Text | Consumer’s national id (up to 30 characters)                 |
| email             | M    | Text | RFC compliant email address of the account holder            |
| address           | M    | Text | Consumer's address                                           |
| zipcode           | M    | Text | Consumer's zip/postal code                                   |
| dob               | O    | Text | Date of birth, format YYYYMMDD                               |

Note: Baloto Cash (Colombia) is available for currency USD and country code CO. 

##### 5.4.5 PPRO_BB

| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |
| consumerref       | M    | Text | Unique reference identifying the consumer, has to satisfy the regular expression [A-Za-z0-9.%,&/+*$-]{1,20} |
| nationalid        | M    | Text | Consumer’s national id (up to 30 characters)                 |
| email             | M    | Text | RFC compliant email address of the account holder            |
| address           | M    | Text | Consumer's address                                           |
| zipcode           | M    | Text | Consumer's zip/postal code                                   |
| dob               | O    | Text | Date of birth, format YYYYMMDD                               |

Note: Banco do Brasil (Brazil) is available for currency USD and country code BR. 

##### 5.4.6 PPRO_BO

| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |
| consumerref       | M    | Text | Unique reference identifying the consumer, has to satisfy the regular expression [A-Za-z0-9.%,&/+*$-]{1,20} |
| nationalid        | M    | Text | Consumer’s national id (up to 30 characters)                 |
| email             | M    | Text | RFC compliant email address of the account holder            |
| address           | M    | Text | Consumer's address                                           |
| zipcode           | M    | Text | Consumer's zip/postal code                                   |
| dob               | O    | Text | Date of birth, format YYYYMMDD                               |

Note: Boleto Bancario is available for currency USD and country code BR. 

##### 5.4.7 PPRO_DR

| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |
| email             | M    | Text | RFC compliant email address of the account holder            |
| phone             | M    | Text | Valid international phone number of the account holder       |

Note: Dragonpay is only available for currency PHP and country code PH. 



##### 5.4.8 PPRO_EN

| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |
| email             | M    | Text | RFC compliant email address of the account holder            |
| phone             | M    | Text | Valid international phone number of the account holder       |

Note: eNETS is only available for currency SGD and country code SG. 

##### 5.4.9 PPRO_EP

| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |

Note: eps only works for the countrycode “AT” and currency “EUR”. 

##### 5.4.10 PPRO_GP

| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |
| bic               | O    | Text | Valid BIC (8 or 11 alphanumeric letters) of consumer’s bank  |

the countrycode “DE” and currency “EUR”. 

##### 5.4.11 PPRO_HC

| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |
| consumerref       | M    | Text | Unique reference identifying the consumer, has to satisfy the regular expression [A-Za-z0-9.%,&/+*$-]{1,20} |
| nationalid        | M    | Text | Consumer’s national id (up to 30 characters)                 |
| email             | M    | Text | RFC compliant email address of the account holder            |
| address           | M    | Text | Consumer's address                                           |
| zipcode           | M    | Text | Consumer's zip/postal code                                   |
| dob               | O    | Text | Date of birth, format YYYYMMDD                               |

Note: Hipercard (Brazil) is available for currency USD and country code BR. 

##### 5.4.12 PPRO_ID

| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |

Note: iDEAL only works for the countrycode “NL” and currency “EUR”. 

Here is the list of currently available issuers and their associated BIC：

![image]()

##### 5.4.13 PPRO_IT

| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |
| consumerref       | M    | Text | Unique reference identifying the consumer, has to satisfy the regular expression [A-Za-z0-9.%,&/+*$-]{1,20} |
| nationalid        | M    | Text | Consumer’s national id (up to 30 characters)                 |
| email             | M    | Text | RFC compliant email address of the account holder            |
| address           | M    | Text | Consumer's address                                           |
| zipcode           | M    | Text | Consumer's zip/postal code                                   |
| dob               | O    | Text | Date of birth, format YYYYMMDD                               |

Note: Itaú (Brazil) is available for currency USD and country code BR.

##### 5.4.14 PPRO_MB



| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |

Note: MyBank only works for the country code IT and currency EUR. 

##### 5.4.15 PPRO_PC



| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |
| consumerref       | M    | Text | Unique reference identifying the consumer, has to satisfy the regular expression [A-Za-z0-9.%,&/+*$-]{1,20} |



##### 5.4.16 PPRO_PU



| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |
| email             | M    | Text | RFC compliant email address of the account holder            |

Note: PayU works only for country code/currency combinations CZ/CZK and PL/PLN. 

##### 5.4.17 PPRO_PL

| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |

Note: POLi only works for the countrycode/currency combinations “NZ”/”NZD” and “AU/AUD”. 

##### 5.4.18 PPRO_P24

| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |
| email             | M    | Text | RFC compliant email address of the account holder            |

Note: Przelewy24 only works for the countrycode “PL” and currencies “PLN” and “EUR”. 

##### 5.4.19 PPRO_QW

| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |
| mobilephone       | M    | Text | Valid international Russian mobile phone number identifying the QIWI destination account to pay out to (excluding plus sign or any other international prefixes, including a leading 7 for Russia, 11 digits in total, e.g. 71234567890). |
| siteid            | M/O  | Text | Unique site identifier, forwarded to qiwi. Required for clients serving multiple points of sale. |

Note:	QIWI Payout only works for the countrycodes “RU”, “KZ” and UA, and - depending on your contract - currency  “RUB” , “EUR” ,”KZT” and “USD”.  

##### 5.4.20 PPRO_SP

| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |
| email             | M    | Text | RFC compliant email address of the account holder            |

Note:SafetyPay only works for country codes “AT”, “BE”, “BR”, “CL”, “CR”, “DE”, “EC”, “ES”, “MX”, “NL”, “PE” and currencies “EUR”, “USD”.

##### 5.4.21 PPRO_SD

| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |

Note: SEPA Direct Debit works for all SEPA countries and currency EUR. 

##### 5.4.22 PPRO_SG

| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |
| email             | M    | Text | RFC compliant email address of the account holder            |
| phone             | M    | Text | Valid international phone number of the account holder       |

Note: SingPost (Singapore) is only available for currency SGD and country code SG. 

##### 5.4.23 PPRO_SK

| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |
| email             | O    | Text | RFC compliant email address of the account holder            |
| address           | O    | Text | Consumer’s address (e.g. street)                             |
| zipcode           | O    | Text | Consumer’s postal code                                       |
| city              | O    | Text | Consumer’s city                                              |

```xml
The account holder name passed in the request has to be in the format <firstname><space><lastname>, with
lastname having a minimum length of two characters and the total string a minimum length of five. Multiple
first names are ok, valid examples are “John Dorian”, “William Charles Dickinson”. If these conditions are not
met, the system will not accept the request 

```

##### 5.4.24 PPRO_SB

| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |
| bic               | O    | Text | Valid BIC (8 or 11 alphanumeric letters) of consumer’s bank  |

OFORT Banking (also known as SOFORT überweisung, formally DirectPay24) is available in Austria, Belgium,
Germany, Spain, Italy and Netherlands (country codes AT, BE, DE, ES, IT, NL). EUR is supported in all countries.

##### 5.4.25 PPRO_TP

| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |

Note: TrustPat   is only available for currency EUR and country code CZ, SK 

##### 5.4.26 PPRO_WP

| Field name        | M/O  | Type | Description                                                  |
| ----------------- | ---- | ---- | ------------------------------------------------------------ |
| countrycode       | M    | Text | The 2-letter ISO country code of the country in which the payment instrument is issued/operated (e.g. DE). For details see payment method specific documentation. |
| accountholdername | M    | Text | The account holder - minimum of 3 characters, up to 100 charac- ters. |
| consumerref       | M    | Text | Unique reference identifying the consumer, has to satisfy the regular expression [A-Za-z0-9.%,&/+*$-]{1,20} |
| nationalid        | M    | Text | Consumer’s national id (up to 30 characters)                 |
| email             | M    | Text | RFC compliant email address of the account holder            |
| address           | M    | Text | Consumer's address                                           |
| zipcode           | M    | Text | Consumer's zip/postal code                                   |
| dob               | O    | Text | Date of birth, format YYYYMMDD                               |

Note: WebPay is available for currency USD and country code CL. 



##### 5.5 AP

| Parameter | Type       | Required | Description                                                  | Sample                                 |
| --------- | ---------- | -------- | ------------------------------------------------------------ | -------------------------------------- |
| timeout   | String(10) | O        | The default is 12h. Please contact Alipay Technical Support if you need to use other values. Max value is 15d. This parameter controls the valid time from login to completion. | 5m 10m 15m 30m 1h 2h 3h 5h 10h 12h 1d. |



##### 5.6 MIPAY(Transition）

| Serial number | Parameter   | Length | Type | Description                                                         |
| ---- | ------ | ---- | ---- | ------------------------------------------------------------ |
| 1    | firstname   | 32   | Text | This is name of the customer who is doing the transaction.   |
| 2    | email   | 40   | Text | This is email id of the customer who is doing transaction.   |
| 3    | phone   | 20   | Text | Phone number of the customer.                                |
| 4    | customerId | 30   | Text | Customer ID, when client register on merchant, merchant distribute it to client. |

```javascript
Test environment configuration：

Modify the test machine hosts file, add the following two information.
114.80.87.249 account.preview.n.xiaomi.net
114.80.87.249 api.account.preview.n.xiaomi.net

Test card：

Card number：5123456789012346
Validity period：0520
cvv：123
```

##### 5.7 IPL(Transition）

| Parameter    | Type       | Required | Description                                                  | Sample |
| ------------ | ---------- | -------- | ------------------------------------------------------------ | ------ |
| language     | string(2)  | O        | The language displayed on the page is Chinese:zh,English:en,Korean:ko                      | zh     |
| terminalType | string(16) | M        | Terminal type: web/h5/android/ios                                  | h5     |
| transTimeout | string(6)  | M        | Effective time of the order, integer format, in minutes (min).                        | 10     |
| country      | string(2)  | O        | National two-character code, need to be capitalized. The page will show you how to pay in this country. If not, the country will display the payment method according to the system. | CN     |

```javascript
Test cards:

Visa：
cardNo: 4000020951595032
expirationMonth: 06
expirationYear: 28
cvv: 688
firstName: Ken 
lastName: Swift

Mastercard:
cardNo: 5333300989521936
expirationMonth: 06 
expirationYear: 28
cvv: 688
firstName: Ken 
lastName: Swift

JCB:
cardNo: 3567860000000000
expirationMonth: 06 
expirationYear: 28
cvv: 688
firstName: Ken 
lastName: Swift

American Express:
cardNo: 375532604034750 
expirationMonth: 06 
expirationYear: 28
cvv: 688
firstName: Ken 
lastName: Swift

Diners Club:
cardNo: 36259600590707 
expirationMonth: 06 
expirationYear: 28
cvv: 688
firstName: Ken 
lastName: Swift

Discover:
cardNo: 6011492100005191 
expirationMonth: 06 
expirationYear: 28
cvv: 688
firstName: Ken 
lastName: Swift
```

#### 5.8 RP(Transition）

| Parameter | Type   | Required | Description                                                | Sample         |
| --------- | ------ | -------- | ---------------------------------------------------------- | -------------- |
| firstname | string | M        | This is name of the customer who is doing the transaction. | jim            |
| email     | string | M        | this is email id of the customer who is doing transaction. | 123456@163.com |

```javascript
Test cards:

Domestic

Mastercard：   
5104_0155_5555_5558, 
5104_0600_0000_0008

Visa:
4111_1111_1111_1111

International

Mastercard:
5555_5555_5555_4444
5105_1051_0510_5100

Visa:
012_8888_8888_1881
4000_1841_8621_8826
```





#### 6.Technical support

If you have problems with debugging, please contact us:support@allpayx.com 







  


